@@ -1,25 +1,25 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2012
- * Mail: info@open-xchange.com
+ * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
 define('io.ox/backbone/modelFactory',
     ['io.ox/backbone/basicModel',
-     'io.ox/core/extensions',
-     'gettext!io.ox/core'], function (BasicModel, ext, gt) {
+     'io.ox/core/extensions'
+    ], function (BasicModel, ext) {
 
     'use strict';
 
     var OXModel = BasicModel.extend({
         idAttribute: '_uid',
-        initialize: function (obj) {
+        initialize: function () {
             BasicModel.prototype.initialize.apply(this, $.makeArray(arguments));
 
             this.realm = this.get('_realm') || this.factory.realm('default');
