@@ -5,6 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
@@ -27,7 +28,8 @@ define('io.ox/calendar/freebusy/controller',
      'gettext!io.ox/calendar/freebusy',
      'settings!io.ox/core',
      'less!io.ox/calendar/week/style.less',
-     'less!io.ox/calendar/freebusy/style.less'], function (dialogs, WeekView, templates, folderAPI, AddParticipantsView, participantsModel, participantsView, userAPI, contactsUtil, api, notifications, date, detailView, gt, settings) {
+     'less!io.ox/calendar/freebusy/style.less'
+    ], function (dialogs, WeekView, templates, folderAPI, AddParticipantsView, participantsModel, participantsView, userAPI, contactsUtil, api, notifications, date, detailView, gt, settings) {
 
     'use strict';
 
@@ -134,12 +136,6 @@ define('io.ox/calendar/freebusy/controller',
                 });
             };
 
-            function toModel(obj) {
-                var model = new Backbone.Model(obj);
-                model.id = _.cid(obj);
-                return model;
-            }
-
             function getColorByIndex(index) {
                 var model = self.participants.at(index);
                 return model ? model.index : 0;
@@ -418,7 +414,7 @@ define('io.ox/calendar/freebusy/controller',
                 self.changeMode(action);
             }
 
-            function clickButton(e) {
+            function clickButton() {
                 var action = $(this).attr('data-action');
                 state.resolve(action);
             }
