@@ -5,6 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
@@ -20,7 +21,9 @@ define('io.ox/calendar/month/perspective',
      'io.ox/calendar/conflicts/conflictList',
      'io.ox/core/print',
      'settings!io.ox/calendar',
-     'gettext!io.ox/calendar'], function (View, api, date, ext, dialogs, detailView, conflictView, print, settings, gt) {
+     'gettext!io.ox/calendar'
+    ], function (View, api, date, ext, dialogs, detailView, conflictView, print, settings, gt) {
+
     'use strict';
 
     var perspective = new ox.ui.Perspective('month');
@@ -30,8 +33,6 @@ define('io.ox/calendar/month/perspective',
         scaffold: $(),      // perspective
         pane: $(),          // scrollpane
         monthInfo: $(),     //
-        showAll: $(),       // show all folders check-box
-        showAllCon: $(),    // container
         tops: {},           // scrollTop positions of the shown weeks
         firstWeek: 0,       // timestamp of the first week
         lastWeek: 0,        // timestamp of the last week
@@ -102,7 +103,7 @@ define('io.ox/calendar/month/perspective',
                 api.update(obj).fail(function (con) {
                     if (con.conflicts) {
                         new dialogs.ModalDialog({
-                                top: "20%",
+                                top: '20%',
                                 center: false,
                                 container: self.main
                             })
@@ -237,7 +238,6 @@ define('io.ox/calendar/month/perspective',
                 $('.day.today', this.pane).removeClass('today');
                 day.addClass('today');
             }
-            this.showAll.prop('checked', settings.get('showAllPrivateAppointments', false));
             var weeks = (this.lastWeek - this.firstWeek) / date.WEEK;
             this.updateWeeks({start: this.firstWeek, weeks: weeks}, useCache);
         },
@@ -280,30 +280,30 @@ define('io.ox/calendar/month/perspective',
 
                 var firstDay = $('#' + param.date.getYear() + '-' + param.date.getMonth() + '-1', self.pane),
                     nextFirstDay = $('#' + param.date.getYear() + '-' + (param.date.getMonth() + 1) + '-1', self.pane),
-                    scrollToDate = function (pos) {
+                    scrollToDate = function () {
                         // scroll to position
                         if (param.duration === 0) {
                             firstDay.get(0).scrollIntoView();
                             self.isScrolling = false;
                         } else {
-                            self.pane.animate({scrollTop : pos + self.scrollTop() + 1}, param.duration, function () {
+                            self.pane.animate({scrollTop : firstDay.position().top + self.scrollTop() + 1}, param.duration, function () {
                                 self.isScrolling = false;
                             });
                         }
                     };
 
                 if (firstDay.length > 0 && nextFirstDay.length > 0) {
-                    scrollToDate(firstDay.position().top);
+                    scrollToDate();
                 } else {
                     if (param.date.getTime() < self.current.getTime()) {
                         this.drawWeeks({up: true}).done(function () {
                             firstDay = $('#' + param.date.getYear() + '-' + param.date.getMonth() + '-1', self.pane);
-                            scrollToDate(firstDay.position().top);
+                            scrollToDate();
                         });
                     } else {
                         this.drawWeeks().done(function () {
                             firstDay = $('#' + param.date.getYear() + '-' + param.date.getMonth() + '-1', self.pane);
-                            scrollToDate(firstDay.position().top);
+                            scrollToDate();
                         });
                     }
                 }
@@ -318,8 +318,6 @@ define('io.ox/calendar/month/perspective',
             var self = this,
                 def = $.Deferred();
             self.app.folder.getData().done(function (data) {
-                // switch only visible on private folders
-                self.showAllCon[data.type === 1 ? 'show' : 'hide']();
                 self.folder = data;
                 def.resolve(data);
             });
@@ -350,6 +348,13 @@ define('io.ox/calendar/month/perspective',
                 template: 'cp_monthview_table_appsuite.tmpl',
                 start: self.current.local,
                 end: end.local
+            }).print();
+        },
+
+        refresh: function () {
+            var self = this;
+            this.getFolder().done(function () {
+                self.update();
             });
         },
 
@@ -370,9 +375,7 @@ define('io.ox/calendar/month/perspective',
                 .append(this.scaffold = View.drawScaffold());
 
             var refresh = function () {
-                self.getFolder().done(function () {
-                    self.update();
-                });
+                self.refresh();
             };
 
             var reload = function () {
@@ -387,20 +390,6 @@ define('io.ox/calendar/month/perspective',
                     .addClass('toolbar')
                     .append(
                         this.monthInfo = $('<div>').addClass('info').text(gt.noI18n(this.current.format('MMMM y'))),
-                        this.showAllCon = $('<div>').addClass('showall')
-                            .append(
-                                $('<label>')
-                                    .addClass('checkbox')
-                                    .text(gt('show all'))
-                                    .prepend(
-                                        this.showAll = $('<input type="checkbox" tabindex="1">')
-                                            .prop('checked', settings.get('showAllPrivateAppointments', false))
-                                            .on('change', $.proxy(function (e) {
-                                                settings.set('showAllPrivateAppointments', this.showAll.prop('checked')).save();
-                                                refresh();
-                                            }, this))
-                                    )
-                            ),
                         $('<div>')
                             .addClass('pagination')
                             .append(
@@ -451,7 +440,7 @@ define('io.ox/calendar/month/perspective',
                         }
                     }
                 }, this))
-                .on('scrollstop', $.proxy(function (e) {
+                .on('scrollstop', $.proxy(function () {
                     var month = false;
 
                     // find first visible month on scroll-position
