@@ -1,130 +1,123 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define("io.ox/calendar/view-detail",
-    ["io.ox/core/extensions",
-     "io.ox/calendar/util",
-     "io.ox/calendar/api",
-     "io.ox/core/api/user",
-     "io.ox/core/api/group",
-     "io.ox/core/api/resource",
-     "io.ox/core/api/folder",
-     "io.ox/core/tk/attachments",
-     "io.ox/core/extPatterns/links",
+define('io.ox/calendar/view-detail',
+    ['io.ox/core/extensions',
+     'io.ox/calendar/util',
+     'io.ox/calendar/api',
+     'io.ox/core/api/user',
+     'io.ox/core/api/group',
+     'io.ox/core/api/resource',
+     'io.ox/core/api/folder',
+     'io.ox/core/tk/attachments',
+     'io.ox/core/extPatterns/links',
      'gettext!io.ox/calendar',
      'io.ox/calendar/actions',
      'less!io.ox/calendar/style.less'
     ], function (ext, util, calAPI, userAPI, groupAPI, resourceAPI, folderAPI, attachments, links, gt) {
 
-    "use strict";
-
-    var fnClickPerson = function (e) {
-        e.preventDefault();
-        ext.point("io.ox/core/person:action").each(function (ext) {
-            _.call(ext.action, e.data, e);
-        });
-    };
+    'use strict';
 
     // draw via extension points
 
     ext.point('io.ox/calendar/detail').extend({
         index: 100,
         id: 'inline-actions',
-        draw: function (data) {
-            ext.point('io.ox/calendar/detail/actions').invoke('draw', this, data);
+        draw: function (baton) {
+            ext.point('io.ox/calendar/detail/actions').invoke('draw', this, baton);
         }
     });
 
     // draw appointment date & time
-    ext.point("io.ox/calendar/detail").extend({
+    ext.point('io.ox/calendar/detail').extend({
         index: 200,
-        id: "date",
-        draw: function (data) {
+        id: 'date',
+        draw: function (baton) {
             var node;
             this.append(node = $('<div class="appointment-date">'));
-            ext.point('io.ox/calendar/detail/date').invoke('draw', node, data);
+            ext.point('io.ox/calendar/detail/date').invoke('draw', node, baton);
         }
     });
 
     // draw appointment time
-    ext.point("io.ox/calendar/detail/date").extend({
+    ext.point('io.ox/calendar/detail/date').extend({
         index: 100,
-        id: "time",
-        draw: function (data) {
+        id: 'time',
+        draw: function (baton) {
             this.append(
-                util.addTimezoneLabel($("<div>").addClass("interval"), data)
+                util.addTimezoneLabel($('<div>').addClass('interval'), baton.data)
             );
         }
     });
 
     // draw date and recurrence information
-    ext.point("io.ox/calendar/detail/date").extend({
+    ext.point('io.ox/calendar/detail/date').extend({
         index: 200,
-        id: "date",
-        draw: function (data) {
-            var recurrenceString = util.getRecurrenceString(data);
+        id: 'date',
+        draw: function (baton) {
+            var recurrenceString = util.getRecurrenceString(baton.data);
             this.append(
-                $("<div>").addClass("day").append(
-                    $.txt(gt.noI18n(util.getDateInterval(data))),
-                    $.txt(gt.noI18n((recurrenceString !== "" ? " \u2013 " + recurrenceString : "")))
+                $('<div>').addClass('day').append(
+                    $.txt(gt.noI18n(util.getDateInterval(baton.data))),
+                    $.txt(gt.noI18n((recurrenceString !== '' ? ' \u2013 ' + recurrenceString : '')))
                 )
             );
         }
     });
 
     // draw private flag
-    ext.point("io.ox/calendar/detail").extend({
+    ext.point('io.ox/calendar/detail').extend({
         index: 250,
-        id: "private-flag",
-        draw: function (data) {
-            if (data.private_flag) {
-                $('<i>').addClass("icon-lock private-flag").appendTo(this);
+        id: 'private-flag',
+        draw: function (baton) {
+            if (baton.data.private_flag) {
+                $('<i>').addClass('icon-lock private-flag').appendTo(this);
             }
         }
     });
 
     // draw title
-    ext.point("io.ox/calendar/detail").extend({
+    ext.point('io.ox/calendar/detail').extend({
         index: 300,
-        id: "title",
-        draw: function (data) {
+        id: 'title',
+        draw: function (baton) {
             this.append(
-                $("<div>").addClass("title clear-title").text(gt.noI18n(data.title || ""))
+                $('<div>').addClass('title clear-title').text(gt.noI18n(baton.data.title || ''))
             );
         }
     });
 
     // draw location
-    ext.point("io.ox/calendar/detail").extend({
+    ext.point('io.ox/calendar/detail').extend({
         index: 400,
-        id: "location",
-        draw: function (data) {
-            if (data.location) {
+        id: 'location',
+        draw: function (baton) {
+            if (baton.data.location) {
                 this.append(
-                    $('<div class="location">').text(gt.noI18n(data.location))
+                    $('<div class="location">').text(gt.noI18n(baton.data.location))
                 );
             }
         }
     });
 
     // draw note/comment
-    ext.point("io.ox/calendar/detail").extend({
+    ext.point('io.ox/calendar/detail').extend({
         index: 500,
-        id: "note",
-        draw: function (data) {
-            if (data.note) {
+        id: 'note',
+        draw: function (baton) {
+            if (baton.data.note) {
                 this.append(
-                    $("<div>").addClass("note").html(util.getNote(data))
+                    $('<div>').addClass('note').html(util.getNote(baton.data))
                 );
             }
         }
@@ -138,11 +131,11 @@ define("io.ox/calendar/view-detail",
     function drawParticipant(obj, hash) {
         // initialize vars
         var key = obj.mail || obj.id,
-            conf = hash[key] || { status: 0, comment: "" },
+            conf = hash[key] || { status: 0, comment: '' },
             confirm = util.getConfirmationSymbol(conf.status),
             statusClass = util.getConfirmationClass(conf.status),
             isPerson = hash[key] || obj.folder_id,
-            personClass = isPerson ? "person" : "",
+            personClass = isPerson ? 'person' : '',
             display_name, name, node, name_lc,
             mail_lc = String(obj.mail || obj.mailaddress || '').toLowerCase();
         // external participant?
@@ -152,7 +145,7 @@ define("io.ox/calendar/view-detail",
             if (name_lc === mail_lc) {
                 name = display_name = mail_lc;
             } else {
-                name = obj.display_name ? obj.display_name + " <" + mail_lc + ">" : mail_lc;
+                name = obj.display_name ? obj.display_name + ' <' + mail_lc + '>' : mail_lc;
                 display_name = obj.display_name || mail_lc;
             }
         } else {
@@ -162,30 +155,30 @@ define("io.ox/calendar/view-detail",
         node = $('<div class="participant">')
             .addClass(looksLikeResource(obj) ? 'halo-resource-link' : 'halo-link')
             .append($('<a href="#">').addClass(personClass + ' ' + statusClass).text(gt.noI18n(name)))
-            .append($('<span>').addClass("status " + statusClass).html(" " + confirm))
+            .append($('<span>').addClass('status ' + statusClass).html(' ' + confirm))
             .data(_.extend(obj, { display_name: display_name, email1: mail_lc }));
         // has confirmation comment?
         if (conf.comment !== '') {
-            node.append($("<span>").addClass("comment").text(gt.noI18n(conf.comment)));
+            node.append($('<span>').addClass('comment').text(gt.noI18n(conf.comment)));
         }
         return node;
     }
 
 
 
-    ext.point("io.ox/calendar/detail").extend({
+    ext.point('io.ox/calendar/detail').extend({
         index: 600,
-        id: "participants",
-        draw: function (data) {
+        id: 'participants',
+        draw: function (baton) {
 
-            var list = data.participants || {}, $i = list.length, MIN = 0,
-                participants = $i > MIN ? $("<div>").addClass("participants") : $(),
+            var list = baton.data.participants || {}, $i = list.length, MIN = 0,
+                participants = $i > MIN ? $('<div>').addClass('participants') : $(),
                 confirmations = {};
 
             // has participants? should always be true. Was $i > 1 (see bug #23295).
             if ($i > MIN) {
 
-                confirmations = util.getConfirmations(data);
+                confirmations = util.getConfirmations(baton.data);
                 participants.busy();
 
                 // get internal users
@@ -229,10 +222,10 @@ define("io.ox/calendar/view-detail",
                     })
                     .value();
 
-                participants.append($("<div>")
-                        .addClass("io-ox-label participants-block").text(gt("Participants")));
+                participants.append($('<div>')
+                        .addClass('io-ox-label participants-block').text(gt('Participants')));
 
-                var plist = $("<div>").addClass("participant-list").appendTo(participants);
+                var plist = $('<div>').addClass('participant-list').appendTo(participants);
 
                 $.when(userAPI.getList(users), groupAPI.getList(groups), resourceAPI.getList(resources))
                 .done(function (userList, groupList, resourceList) {
@@ -248,9 +241,9 @@ define("io.ox/calendar/view-detail",
                     //external Participants get their own section
                     var extList;
                     if (external.length > 0) {
-                        participants.append($("<div>")
-                                .addClass("io-ox-label participants-block").text(gt("External participants")),
-                                extList = $("<div>").addClass("participant-list"));
+                        participants.append($('<div>')
+                                .addClass('io-ox-label participants-block').text(gt('External participants')),
+                                extList = $('<div>').addClass('participant-list'));
                     }
                     // loop over external participants
                     _(external).each(function (obj) {
@@ -269,8 +262,8 @@ define("io.ox/calendar/view-detail",
                             if (memberList.length) {
                                 // new section
                                 participants
-                                    .append($("<div>").addClass("group").text(gt.noI18n(obj.display_name + ":")))
-                                    .append(glist = $("<div>").addClass("participant-list"));
+                                    .append($('<div>').addClass('group').text(gt.noI18n(obj.display_name + ':')))
+                                    .append(glist = $('<div>').addClass('participant-list'));
                                 userAPI.getList(memberList)
                                     .done(function (members) {
                                         // loop members
@@ -288,8 +281,8 @@ define("io.ox/calendar/view-detail",
                     // resources
                     if (resourceList.length) {
                         participants
-                            .append($("<div>").addClass("io-ox-label").text(gt("Resources")))
-                            .append(plist = $("<div>").addClass("participant-list"));
+                            .append($('<div>').addClass('io-ox-label').text(gt('Resources')))
+                            .append(plist = $('<div>').addClass('participant-list'));
                         // loop over resources
                         _(resourceList)
                             .chain()
@@ -304,7 +297,7 @@ define("io.ox/calendar/view-detail",
                 .always(function () {
                     // finish
                     participants.idle()
-                        .append($("<div>").addClass("participants-clear"));
+                        .append($('<div>').addClass('participants-clear'));
                 });
             }
 
@@ -316,61 +309,85 @@ define("io.ox/calendar/view-detail",
     ext.point('io.ox/calendar/detail').extend({
         index: 700,
         id: 'inline-actions-participantrelated',
-        draw: function (data) {
-            if (data.participants && data.participants.length > 1) {
-                ext.point('io.ox/calendar/detail/actions-participantrelated').invoke('draw', this, data);
+        draw: function (baton) {
+            if (baton.data.participants && baton.data.participants.length > 1) {
+                ext.point('io.ox/calendar/detail/actions-participantrelated').invoke('draw', this, baton);
             }
 
         }
     });
 
     // draw details
-    ext.point("io.ox/calendar/detail").extend({
+    ext.point('io.ox/calendar/detail').extend({
         index: 800,
-        id: "details",
-        draw: function (data, options) {
-            if (options && options.brief) {
-                return $();
-            }
-            var node = $("<div>").addClass('details')
-                .append($("<div>").addClass("io-ox-label").text(gt("Details")))
+        id: 'details',
+        draw: function (baton) {
+            var node = $('<div>').addClass('details')
+                .append($('<div>').addClass('io-ox-label').text(gt('Details')))
                 .appendTo(this);
-            ext.point("io.ox/calendar/detail/details").invoke("draw", node, data);
+            ext.point('io.ox/calendar/detail/details').invoke('draw', node, baton);
+        }
+    });
+
+    // organizer
+    ext.point('io.ox/calendar/detail/details').extend({
+        index: 100,
+        id: 'organizer',
+        draw: function (baton) {
+
+            // internal or external organizer?
+            if (!baton.data.organizerId && !baton.data.organizer) return;
+
+            this.append(
+                $('<span class="detail-label">').append(
+                    $.txt(gt('Organizer')), $.txt(gt.noI18n(':\u00A0'))
+                ),
+                $('<span class="detail organizer">').append(
+                    baton.data.organizerId ?
+                        $('<a href="#" class="halo-link">').data({ user_id: baton.data.organizerId }).append(
+                            userAPI.getTextNode(baton.data.organizerId)
+                        ) :
+                        $('<a href="#" class="halo-link">').data({ email1: baton.data.organizer }).text(
+                            baton.data.organizer
+                        )
+                ),
+                $('<br>')
+             );
         }
     });
 
     // show as
-    ext.point("io.ox/calendar/detail/details").extend({
-        index: 100,
-        id: "shownAs",
-        draw: function (data) {
+    ext.point('io.ox/calendar/detail/details').extend({
+        index: 200,
+        id: 'shownAs',
+        draw: function (baton) {
             this.append(
-                $("<span>")
-                    .addClass("detail-label")
-                    .append($.txt(gt("Show as")), $.txt(gt.noI18n(":\u00A0"))),
-                $("<span>")
-                    .addClass("detail shown_as " + util.getShownAsClass(data))
-                    .text(gt.noI18n("\u00A0")),
-                $("<span>")
-                    .addClass("detail shown-as")
-                    .append($.txt(gt.noI18n("\u00A0")), $.txt(util.getShownAs(data))),
-                $("<br>")
+                $('<span>')
+                    .addClass('detail-label')
+                    .append($.txt(gt('Show as')), $.txt(gt.noI18n(':\u00A0'))),
+                $('<span>')
+                    .addClass('detail shown_as ' + util.getShownAsClass(baton.data))
+                    .text(gt.noI18n('\u00A0')),
+                $('<span>')
+                    .addClass('detail shown-as')
+                    .append($.txt(gt.noI18n('\u00A0')), $.txt(util.getShownAs(baton.data))),
+                $('<br>')
             );
         }
     });
 
     // folder
-    ext.point("io.ox/calendar/detail/details").extend({
-        index: 200,
-        id: "folder",
-        draw: function (data) {
-            if (data.folder_id) {
+    ext.point('io.ox/calendar/detail/details').extend({
+        index: 300,
+        id: 'folder',
+        draw: function (baton) {
+            if (baton.data.folder_id) {
                 this.append(
                     $('<span class="detail-label">')
-                        .append($.txt(gt("Folder")), $.txt(gt.noI18n(":\u00A0"))),
+                        .append($.txt(gt('Folder')), $.txt(gt.noI18n(':\u00A0'))),
                     $('<span class="detail folder">')
-                        .attr('data-folder', data.folder_id)
-                        .append(folderAPI.getTextNode(data.folder_id)),
+                        .attr('data-folder', baton.data.folder_id)
+                        .append(folderAPI.getTextNode(baton.data.folder_id)),
                     $('<br>')
                 );
             }
@@ -378,20 +395,20 @@ define("io.ox/calendar/view-detail",
     });
 
     // created on/by
-    ext.point("io.ox/calendar/detail/details").extend({
-        index: 200,
-        id: "created",
-        draw: function (data) {
-            if (data.creation_date || data.created_by) {
+    ext.point('io.ox/calendar/detail/details').extend({
+        index: 400,
+        id: 'created',
+        draw: function (baton) {
+            if (baton.data.creation_date || baton.data.created_by) {
                 this.append(
                     $('<span class="detail-label">').append(
                         $.txt(gt('Created')), $.txt(gt.noI18n(':\u00A0'))
                     ),
                     $('<span class="detail created">').append(
-                        $('<span>').text(gt.noI18n(data.creation_date ? util.getDate(data.creation_date) : '')),
-                        $('<span>').text(gt.noI18n(data.creation_date ? ' \u2013 ' : '')),
-                        $('<a href="#" class="halo-link">').data({ user_id: data.created_by }).append(
-                            data.created_by ? userAPI.getTextNode(data.created_by) : ''
+                        $('<span>').text(gt.noI18n(baton.data.creation_date ? util.getDate(baton.data.creation_date) : '')),
+                        $('<span>').text(gt.noI18n(baton.data.creation_date ? ' \u2013 ' : '')),
+                        $('<a href="#" class="halo-link">').data({ user_id: baton.data.created_by }).append(
+                            baton.data.created_by ? userAPI.getTextNode(baton.data.created_by) : ''
                         )
                     ),
                     $('<br>')
@@ -401,20 +418,20 @@ define("io.ox/calendar/view-detail",
     });
 
     // modified on/by
-    ext.point("io.ox/calendar/detail/details").extend({
-        index: 200,
-        id: "modified",
-        draw: function (data) {
-            if (data.last_modified || data.modified_by) {
+    ext.point('io.ox/calendar/detail/details').extend({
+        index: 500,
+        id: 'modified',
+        draw: function (baton) {
+            if (baton.data.last_modified || baton.data.modified_by) {
                 this.append(
                     $('<span class="detail-label">').append(
                         $.txt(gt('Modified')), $.txt(gt.noI18n(':\u00A0'))
                     ),
                     $('<span class="detail modified">').append(
-                        $('<span>').text(gt.noI18n(data.last_modified ? util.getDate(data.last_modified) : '')),
-                        $('<span>').text(gt.noI18n(data.last_modified ? ' \u2013 ' : '')),
-                        $('<a href="#" class="halo-link">').data({ user_id: data.modified_by }).append(
-                            data.modified_by ? userAPI.getTextNode(data.modified_by) : ''
+                        $('<span>').text(gt.noI18n(baton.data.last_modified ? util.getDate(baton.data.last_modified) : '')),
+                        $('<span>').text(gt.noI18n(baton.data.last_modified ? ' \u2013 ' : '')),
+                        $('<a href="#" class="halo-link">').data({ user_id: baton.data.modified_by }).append(
+                            baton.data.modified_by ? userAPI.getTextNode(baton.data.modified_by) : ''
                         )
                     ),
                     $('<br>')
@@ -423,66 +440,46 @@ define("io.ox/calendar/view-detail",
         }
     });
 
-    // organizer
-    ext.point("io.ox/calendar/detail/details").extend({
-        index: 200,
-        id: "organizer",
-        draw: function (data) {
-            if (data.organizerId) {
-                this.append(
-                    $('<span class="detail-label">').append(
-                        $.txt(gt('Organizer')), $.txt(gt.noI18n(':\u00A0'))
-                    ),
-                    $('<span class="detail organizer">').append(
-                        $('<a href="#" class="halo-link">').data({ user_id: data.organizerId }).append(
-                            data.organizerId ? userAPI.getTextNode(data.organizerId) : ''
-                        )
-                    ),
-                    $('<br>')
-                 );
-            }
-        }
-    });
-
-    ext.point("io.ox/calendar/detail").extend({
+    ext.point('io.ox/calendar/detail').extend({
         id: 'attachments',
         index: 550,
-        draw: function (data) {
+        draw: function (baton) {
             var $node;
-            if (calAPI.uploadInProgress(_.ecid(data))) {
+            if (calAPI.uploadInProgress(_.ecid(baton.data))) {
                 this.append(
                         $('<div class="io-ox-label">').text(gt('Attachments')),
                         $node = $('<div>').css({width: '30%', height: '12px'}).busy()
                     );
-            } else if (data.number_of_attachments && data.number_of_attachment !== 0) {
+            } else if (baton.data.number_of_attachments && baton.data.number_of_attachment !== 0) {
                 this.append(
                     $('<div class="io-ox-label">').text(gt('Attachments')),
                     $node = $('<div>')
                 );
-                ext.point("io.ox/calendar/detail/attachments").invoke('draw', $node, new ext.Baton({ data: data }));
+                ext.point('io.ox/calendar/detail/attachments').invoke('draw', $node, baton);
             }
         }
     });
 
-    ext.point("io.ox/calendar/detail/attachments").extend(new attachments.AttachmentList({
+    ext.point('io.ox/calendar/detail/attachments').extend(new attachments.AttachmentList({
         id: 'attachment-list',
         index: 200,
         module: 1,
         selector: '.window-container.io-ox-calendar-window'
     }));
 
-    function redraw(e, data) {
-        $(this).replaceWith(e.data.view.draw(data));
+    function redraw(e, baton) {
+        $(this).replaceWith(e.data.view.draw(baton));
     }
 
     return {
 
-        draw: function (data, options) {
-
+        draw: function (baton, options) {
+            // make sure we have a baton
+            baton = ext.Baton.ensure(baton);
             try {
-                var node = $.createViewContainer(data, calAPI).on('redraw', { view: this }, redraw);
-                node.addClass('calendar-detail view user-select-text').attr('data-cid', String(_.cid(data)));
-                ext.point("io.ox/calendar/detail").invoke("draw", node, data, options);
+                var node = $.createViewContainer(baton.data, calAPI).on('redraw', { view: this }, redraw);
+                node.addClass('calendar-detail view user-select-text').attr('data-cid', String(_.cid(baton.data)));
+                ext.point('io.ox/calendar/detail').invoke('draw', node, baton, options);
 
                 return node;
 
