@@ -1,11 +1,12 @@
 /**
- * All content on this website (including text, images, source code and any
- * other original works), unless otherwise noted, is licensed under a Creative
- * Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011 Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
@@ -35,7 +36,7 @@ define('io.ox/contacts/distrib/create-dist-view',
         id: 'title-controls',
         index: 100,
         className: 'row-fluid title-controls',
-        render: function (baton) {
+        render: function () {
             var self = this,
             buttonText = (self.model.get('id')) ? gt('Save') : gt('Create list');
 
@@ -68,7 +69,6 @@ define('io.ox/contacts/distrib/create-dist-view',
         label: gt('List name'), // noun
         control: '<input tabindex="1" type="text" class="span6">',
         buildControls: function () {
-            var self = this;
             return this.nodes.controls || (this.nodes.controls = $('<div class="controls">').append(
                 // element
                 this.buildElement()
@@ -80,7 +80,7 @@ define('io.ox/contacts/distrib/create-dist-view',
         id: 'add-members',
         index: 300,
         className: 'row-fluid',
-        render: function (baton) {
+        render: function () {
             var self = this;
 
             var pNode = $('<div class="autocomplete-controls input-append">').append(
@@ -272,38 +272,14 @@ define('io.ox/contacts/distrib/create-dist-view',
     point.extend({
         id: 'notice',
         index: 400,
-        render: function (baton) {
+        render: function () {
             this.$el.append($('<div class="alert alert-info">').text(gt('To add contacts manually, just provide a valid email address (e.g john.doe@example.com or "John Doe" <jd@example.com>)')));
         }
     });
 
-    /**
-    * remove already used items
-    *
-    * @return {object} data (list, hits)
-    */
-    function filterUsed(data, node) {
-        var self = this,
-            currentMembers = self.model.get('distribution_list') || {},
-            hash = {},
-            list;
-
-        _(currentMembers).each(function (val) {
-            hash[val.mail] = true;
-        });
-
-        // ignore doublets
-        list = _(data).filter(function (member) {
-            return (hash[member.email] === undefined);
-        }, this);
-
-        //return number of query hits and the filtered list
-        return { list: list, hits: data.length};
-    }
-
     ext.point('io.ox/contacts/model/validation/distribution_list').extend({
         id: 'check_for_duplicates',
-        validate: function (value) {
+        validate: function () {
         }
     });
 
