@@ -1,12 +1,12 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2012
- * Mail: info@open-xchange.com
+ * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
@@ -17,14 +17,13 @@ define('io.ox/contacts/distrib/main',
      'io.ox/contacts/model',
      'io.ox/contacts/distrib/create-dist-view',
      'gettext!io.ox/contacts',
-     'io.ox/contacts/util',
      'less!io.ox/contacts/distrib/style.less'
-     ], function (api, contactModel, ContactCreateDistView, gt, util) {
+    ], function (api, contactModel, ContactCreateDistView, gt) {
 
     'use strict';
 
     // multi instance pattern
-    function createInstance(data, mainapp) {
+    function createInstance(data) {
 
         var app,
             win,
@@ -37,7 +36,8 @@ define('io.ox/contacts/distrib/main',
         app = ox.ui.createApp({
             name: 'io.ox/contacts/distrib',
             title: gt('Distribution List'),
-            userContent: true
+            userContent: true,
+            closable: true
         });
 
         app.create = function (folderId, initdata) {
@@ -70,12 +70,12 @@ define('io.ox/contacts/distrib/main',
             });
 
             view.on('save:fail', function () {
-                require("io.ox/core/notifications").yell("error", gt("Failed to save distribution list."));
+                require('io.ox/core/notifications').yell('error', gt('Failed to save distribution list.'));
                 win.idle();
             });
 
             view.on('save:success', function () {
-                require("io.ox/core/notifications").yell("success", gt("Distribution list has been saved"));
+                require('io.ox/core/notifications').yell('success', gt('Distribution list has been saved'));
                 considerSaved = true;
                 win.idle();
                 app.quit();
@@ -130,18 +130,16 @@ define('io.ox/contacts/distrib/main',
             }));
 
             function fnToggleSave(isDirty) {
-                var node = container.find('.btn[data-action="save"]');
-                if (isDirty) node.removeAttr('disabled'); else node.attr('disabled', 'disabled');
+                container.find('.btn[data-action="save"]').prop('disabled', !isDirty);
             }
 
             win.on('show', function () {
                 if (!container.find('[data-extension-id="displayname"] input').val()) {
-                    container.find('.btn[data-action="save"]').attr('disabled', 'disabled');
+                    container.find('.btn[data-action="save"]').prop('disabled', true);
                 }
                 container.find('input[type=text]:visible').eq(0).focus();
                 container.find('[data-extension-id="displayname"] input').on('keyup', _.debounce(function () {
-                    var title = _.noI18n($.trim($(this).val()));
-                    app.setTitle(title);
+                    app.setTitle(_.noI18n($.trim($(this).val())) || gt('Distribution List'));
                     fnToggleSave($(this).val());
                 }, 150));
             });
@@ -168,8 +166,8 @@ define('io.ox/contacts/distrib/main',
                     require(['io.ox/core/tk/dialogs'], function (dialogs) {
                         new dialogs.ModalDialog()
                             .text(gt('Do you really want to discard your changes?'))
-                            .addPrimaryButton('delete', gt('Discard'))
-                            .addButton('cancel', gt('Cancel'))
+                            .addPrimaryButton('delete', gt('Discard'), 'delete', {'tabIndex': '1'})
+                            .addButton('cancel', gt('Cancel'), 'cancel', {'tabIndex': '1'})
                             .show()
                             .done(function (action) {
                                 if (action === 'delete') {
@@ -210,6 +208,3 @@ define('io.ox/contacts/distrib/main',
     };
 
 });
-
-
-
