@@ -1,21 +1,24 @@
 /**
- * All content on this website (including text, images, source code and any
- * other original works), unless otherwise noted, is licensed under a Creative
- * Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011 Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
  */
 
-define("io.ox/contacts/distrib/test",
-    ["io.ox/core/extensions", "io.ox/contacts/main",
-     "io.ox/contacts/api"], function (ext, contacts, api) {
+define('io.ox/contacts/distrib/test',
+    ['io.ox/core/extensions',
+     'io.ox/contacts/main',
+     'io.ox/contacts/api'
+    ], function (ext, contacts, api) {
 
-    "use strict";
+    'use strict';
 
     // test objects
     var testObjects = {
@@ -66,9 +69,9 @@ define("io.ox/contacts/distrib/test",
         index: 100,
         test: function (j) {
 
-            j.describe("Contact distrib", function () {
+            j.describe('Contact distrib', function () {
 
-                var app = null, buttonCreate, createForm, inputName, inputMail, addButton,
+                var app = null, buttonCreate, createForm, inputName, addButton,
                 saveButton, displayName, dataId, dataObj, dataFolder;
 
                 j.it('opens contact app ', function () {
@@ -197,7 +200,7 @@ define("io.ox/contacts/distrib/test",
 
                 j.it('looks for the saved item / selects and deletes', function () {
 
-                    var item, button, dialog,
+                    var button, dialog,
                         cid = dataFolder + '.' + dataId,
                         grid = app.getGrid();
 
