@@ -1,6 +1,10 @@
-define('io.ox/contacts/edit/try', ['io.ox/contacts/model', 'io.ox/contacts/edit/view-form', 'io.ox/core/tk/dialogs'], function (model, view, dialogs) {
+define('io.ox/contacts/edit/try',
+    ['io.ox/contacts/model',
+     'io.ox/contacts/edit/view-form',
+     'io.ox/core/tk/dialogs'
+    ], function (model, view, dialogs) {
 
-    "use strict";
+    'use strict';
 
     var view = new view.ContactEditView({model: window.c = model.factory.create({'suffix': 'Hajj', 'spouse_name': 'Marianne'})});
     // create modal popup
@@ -16,10 +20,7 @@ define('io.ox/contacts/edit/try', ['io.ox/contacts/model', 'io.ox/contacts/edit/
     pane.addPrimaryButton('save', 'Save')
         .addButton('cancel', 'Cancel');
 
-
     pane.show();
 
     return {};
-
-
 });
