@@ -261,17 +261,17 @@ define('io.ox/contacts/model',
         city_other: gt('Town'),
         postal_code_other: gt('Postcode'),
         country_other: gt('Country'),
-        telephone_business1: gt('Phone'),
-        telephone_business2: gt('Phone alt'),
+        telephone_business1: gt('Phone (business)'),
+        telephone_business2: gt('Phone (business alt)'),
         fax_business: gt('Fax'),
         telephone_callback: gt('Telephone callback'),
         telephone_car: gt('Phone (car)'),
         telephone_company: gt('Phone (company)'),
-        telephone_home1: gt('Phone (Home)'),
-        telephone_home2: gt('Phone (Home alt)'),
+        telephone_home1: gt('Phone (home)'),
+        telephone_home2: gt('Phone (home alt)'),
         fax_home: gt('Fax (Home)'),
         cellular_telephone1: gt('Cell phone'),
-        cellular_telephone2: gt('Cell phone alt'),
+        cellular_telephone2: gt('Cell phone (alt)'),
         telephone_other: gt('Phone (other)'),
         fax_other: gt('Fax (alt)'),
         email1: capabilities.has('msisdn') ? gt('Email 1 / Phone number') : gt('Email 1'),
