@@ -1,29 +1,31 @@
 /**
- * All content on this website (including text, images, source code and any
- * other original works), unless otherwise noted, is licensed under a Creative
- * Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011 Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
  */
 
-define("io.ox/contacts/view-detail",
-    ["io.ox/core/extensions",
-     "gettext!io.ox/contacts",
-     "io.ox/contacts/util",
-     "io.ox/contacts/api",
-     "io.ox/contacts/actions",
-     "io.ox/core/api/folder",
+define('io.ox/contacts/view-detail',
+    ['io.ox/core/extensions',
+     'gettext!io.ox/contacts',
+     'io.ox/contacts/util',
+     'io.ox/contacts/api',
+     'io.ox/contacts/actions',
+     'io.ox/contacts/model',
+     'io.ox/core/api/folder',
      'io.ox/core/extPatterns/links',
      'io.ox/core/date',
-     "less!io.ox/contacts/style.less"
-    ], function (ext, gt, util, api, actions, folderAPI, links, date) {
+     'less!io.ox/contacts/style.less'
+    ], function (ext, gt, util, api, actions, model, folderAPI, links, date) {
 
-    "use strict";
+    'use strict';
 
     // smart join
     var join = function () {
@@ -31,7 +33,7 @@ define("io.ox/contacts/view-detail",
             .select(function (obj, i) {
                 return i > 0 && !!obj;
             })
-            .join(arguments[0] || "");
+            .join(arguments[0] || '');
     };
 
     function getDescription(data) {
@@ -71,9 +73,6 @@ define("io.ox/contacts/view-detail",
         return (/<\w/).test(str);
     }
 
-    function attachmentFail(container, contact) {
-    }
-
     function buildDropdown(container, label, data) {
         return new links.DropdownLinks({
             label: label,
@@ -88,19 +87,19 @@ define("io.ox/contacts/view-detail",
 
     var INDEX = 100;
 
-    ext.point("io.ox/contacts/detail").extend({
+    ext.point('io.ox/contacts/detail').extend({
         index: (INDEX += 100),
-        id: "inline-actions",
+        id: 'inline-actions',
         draw: function (baton) {
             if (!api.looksLikeResource(baton.data)) {
-                ext.point("io.ox/contacts/detail/actions").invoke("draw", this, baton.data);
+                ext.point('io.ox/contacts/detail/actions').invoke('draw', this, baton.data);
             }
         }
     });
 
-    ext.point("io.ox/contacts/detail").extend({
+    ext.point('io.ox/contacts/detail').extend({
         index: (INDEX += 100),
-        id: "contact-details",
+        id: 'contact-details',
         draw: function (baton) {
             var node;
             this.append(
@@ -112,7 +111,7 @@ define("io.ox/contacts/view-detail",
 
     // HEAD
 
-    ext.point("io.ox/contacts/detail/head").extend({
+    ext.point('io.ox/contacts/detail/head').extend({
         index: 100,
         id: 'contact-picture',
         draw: function (baton) {
@@ -124,7 +123,7 @@ define("io.ox/contacts/view-detail",
         }
     });
 
-    ext.point("io.ox/contacts/detail/head").extend({
+    ext.point('io.ox/contacts/detail/head').extend({
         index: 200,
         id: 'contact-title',
         draw: function (baton) {
@@ -173,7 +172,7 @@ define("io.ox/contacts/view-detail",
                 api.getAll({ folder_id: contact.folder_id, id: contact.id, module: 7 }).then(
                     function success(data) {
                         section.empty();
-                        _(data).each(function (a, index) {
+                        _(data).each(function (a) {
                             // draw
                             buildDropdown(section, _.noI18n(a.filename), a);
                         });
@@ -196,9 +195,9 @@ define("io.ox/contacts/view-detail",
 
     // Content
 
-    ext.point("io.ox/contacts/detail").extend({
+    ext.point('io.ox/contacts/detail').extend({
         index: (INDEX += 100),
-        id: "contact-content",
+        id: 'contact-content',
         draw: function (baton) {
 
             var node = $('<article>').appendTo(this),
@@ -212,7 +211,7 @@ define("io.ox/contacts/view-detail",
 
     // Distribution list members
 
-    ext.point("io.ox/contacts/detail/member").extend({
+    ext.point('io.ox/contacts/detail/member').extend({
 
         draw: function (data) {
             // draw member
@@ -226,7 +225,7 @@ define("io.ox/contacts/view-detail",
         }
     });
 
-    ext.point("io.ox/contacts/detail/list").extend({
+    ext.point('io.ox/contacts/detail/list').extend({
 
         draw: function (baton) {
 
@@ -251,45 +250,39 @@ define("io.ox/contacts/view-detail",
                     }
                 })
                 .each(function (member) {
-                    ext.point("io.ox/contacts/detail/member").invoke('draw', this, member);
+                    ext.point('io.ox/contacts/detail/member').invoke('draw', this, member);
                 }, this);
         }
     });
 
-    function block(legend, list) {
+    function block() {
 
         var args = _(arguments).toArray(),
             rows = _(args.slice(1)).compact();
 
-        if (rows.length === 0) return [];
+        if (rows.length === 0) return $();
 
         return $('<div class="block">').append(
             [$('<legend>').text(args[0])].concat(rows)
         );
     }
 
-    function row(label, builder) {
-
-        if (_.isFunction(label)) {
-            builder = label;
-            label = null;
-        }
+    function row(id, builder) {
 
         var build = builder();
-
         if (!build) return null;
 
-        return $('<div>').append(
-            label ? $('<label>').text(label) : [],
+        return $('<div>').attr('data-property', id).append(
+            $('<label>').text(model.fields[id]),
             _.isString(build) ? $.txt(build) : build
         );
     }
 
-    function simple(label, value) {
-        value = $.trim(value);
+    function simple(data, id, label) {
+        var value = $.trim(data[id]);
         if (!value) return null;
-        return $('<div>').append(
-            $('<label>').text(label),
+        return $('<div>').attr('data-property', id).append(
+            $('<label>').text(label || model.fields[id]),
             $('<span>').text(value)
         );
     }
@@ -306,9 +299,9 @@ define("io.ox/contacts/view-detail",
         });
     }
 
-    function mail(address, name) {
+    function mail(address, name, id) {
         if (!address) return null;
-        return $('<div>').append(
+        return $('<div>').attr('data-property', id).append(
             $('<label>').text(gt('Email')),
             $('<a>', { href: 'mailto:' + address })
                 .text(_.noI18n(address))
@@ -327,23 +320,25 @@ define("io.ox/contacts/view-detail",
             .value();
     }
 
-    function phone(label, number) {
-        number = $.trim(number);
+    function phone(data, id, label) {
+        var number = $.trim(data[id]);
         if (!number) return null;
-        return $('<div>').append(
-            $('<label>').text(label),
-            $('<a>', { href: _.device('smartphone') ? 'tel:' + number: 'callto:' + number }).text(number)
+        return $('<div>').attr('data-property', id).append(
+            $('<label>').text(label || model.fields[id]),
+            $('<a>', { href: _.device('smartphone') ? 'tel:' + number : 'callto:' + number }).text(number)
         );
     }
 
-    function IM(number) {
+    function IM(number, id) {
 
         number = $.trim(number);
         if (!number) return null;
 
+        var node = $('<div>').attr('data-property', id), obj = {};
+
         if (/^skype:/.test(number)) {
             number = number.split('skype:')[1];
-            return $('<div>').append(
+            return node.append(
                 $('<label>').text('Skype'),
                 $('<a>', { href: 'callto:' + number + '?call' }).text(number)
             );
@@ -351,13 +346,14 @@ define("io.ox/contacts/view-detail",
 
         if (/^x-apple:/.test(number)) {
             number = number.split('x-apple:')[1];
-            return $('<div>').append(
+            return node.append(
                 $('<label>').text('iMessage'),
                 $('<a>', { href: 'imessage://' + number + '@me.com' }).text(number)
             );
         }
 
-        return simple(gt('Messenger'), number);
+        obj[id] = number;
+        return simple(id, gt('Messenger'), obj);
     }
 
     // data is full contact data
@@ -381,6 +377,7 @@ define("io.ox/contacts/view-detail",
 
         return $('<a class="google-maps" target="_blank">')
             .attr('href', 'http://www.google.com/maps?q=' + encodeURIComponent(text.replace('/\n/g', ', ')))
+            .attr('data-property', type)
             .append(
                 $.txt($.trim(text)),
                 $('<caption>').append(
@@ -390,11 +387,11 @@ define("io.ox/contacts/view-detail",
             );
     }
 
-    ext.point("io.ox/contacts/detail/content")
+    ext.point('io.ox/contacts/detail/content')
 
         // Contact note/comment
         .extend({
-            id: "comment",
+            id: 'comment',
             index: 100,
             draw: function (baton) {
 
@@ -407,25 +404,22 @@ define("io.ox/contacts/view-detail",
             }
         })
 
-        // Personal
         .extend({
             id: 'personal',
             index: 200,
             draw: function (baton) {
 
                 var data = baton.data,
-                    addresses = getMailAddresses(data),
                     fullname = util.getFullName(baton.data);
 
                 this.append(
-
                     block(gt('Personal'),
-                        simple(gt('Title'), data.title),
-                        simple(gt('Name'), fullname),
-                        simple(gt('Middle name'), data.second_name),
-                        simple(gt('Suffix'), data.suffix),
-                        simple(gt('Nickname'), data.nickname),
-                        row(gt('Birthday'), function () {
+                        simple(data, 'title'),
+                        simple({ fullname: fullname }, 'name', gt('Name')),
+                        simple(data, 'second_name'),
+                        simple(data, 'suffix'),
+                        simple(data, 'nickname'),
+                        row('birthday', function () {
                             if (baton.data.birthday) {
                                 var birthday = new date.UTC(baton.data.birthday);//use utc time. birthdays must not be converted
                                 if (birthday.getYear() === 1) {//Year 0 is special for birthdays without year (backend changes this to 1...)
@@ -435,83 +429,170 @@ define("io.ox/contacts/view-detail",
                                 }
                             }
                         }),
-                        row(gt('URL'), function () {
-                            if (baton.data.url)
+                        row('URL', function () {
+                            if (baton.data.url) {
                                 return $('<a>', { href: baton.data.url, target: '_blank' }).text(baton.data.url);
+                            }
                         })
-                    ),
+                    )
+                    .attr('data-block', 'personal')
+                );
+            }
+        })
 
+        .extend({
+            id: 'job',
+            index: 300,
+            draw: function (baton) {
+
+                var data = baton.data;
+
+                this.append(
                     block(gt('Job'),
-                        simple(gt('Position'), data.position),
-                        simple(gt('Department'), data.department),
-                        simple(gt('Profession'), data.profession),
-                        simple(gt('Company'), data.company),
-                        simple(gt('Room number'), data.room_number)
-                    ),
+                        simple(data, 'position'),
+                        simple(data, 'department'),
+                        simple(data, 'profession'),
+                        simple(data, 'company'),
+                        simple(data, 'room_number')
+                    )
+                    .attr('data-block', 'job')
+                );
+            }
+        })
 
+        .extend({
+            id: 'messaging',
+            index: 400,
+            draw: function (baton) {
+
+                var data = baton.data,
+                    fullname = util.getFullName(baton.data),
+                    addresses = getMailAddresses(data);
+
+                this.append(
                     block(gt('Mail and Messaging'),
-                        mail(addresses[0], fullname),
-                        mail(addresses[1], fullname),
-                        mail(addresses[2], fullname),
-                        IM(data.instant_messenger1),
-                        IM(data.instant_messenger2)
-                    ),
+                        mail(addresses[0], fullname, 'email1'),
+                        mail(addresses[1], fullname, 'email2'),
+                        mail(addresses[2], fullname, 'email3'),
+                        IM(data.instant_messenger1, 'instant_messenger1'),
+                        IM(data.instant_messenger2, 'instant_messenger2')
+                    )
+                    .attr('data-block', 'messaging')
+                );
+            }
+        })
 
+        .extend({
+            id: 'phone',
+            index: 500,
+            draw: function (baton) {
+
+                var data = baton.data;
+
+                this.append(
                     block(gt('Phone numbers'),
-                        phone(gt('Mobile'), data.cellular_telephone1),
-                        phone(gt('Mobile'), data.cellular_telephone2),
-                        phone(gt('Phone (business)'), data.telephone_business1),
-                        phone(gt('Phone (business)'), data.telephone_business2),
-                        phone(gt('Phone (private)'), data.telephone_home1),
-                        phone(gt('Phone (private)'), data.telephone_home2),
-                        phone(gt('Phone (other)'), data.telephone_other),
-                        simple(gt('Fax (business)'), data.fax_business),
-                        simple(gt('Fax (private)'), data.fax_home),
-                        simple(gt('Fax (other)'), data.fax_other)
-                    ),
+                        phone(data, 'cellular_telephone1'),
+                        phone(data, 'cellular_telephone2'),
+                        phone(data, 'telephone_business1'),
+                        phone(data, 'telephone_business2'),
+                        phone(data, 'telephone_home1'),
+                        phone(data, 'telephone_home2'),
+                        phone(data, 'telephone_other'),
+                        simple(data, 'fax_business'),
+                        simple(data, 'fax_home'),
+                        simple(data, 'fax_other')
+                    )
+                    .attr('data-block', 'phone')
+                );
+            }
+        })
 
+        .extend({
+            id: 'business-address',
+            index: 600,
+            draw: function (baton) {
+
+                var data = baton.data;
+
+                this.append(
                     block(gt('Business Address'),
                         address(data, 'business')
-                    ),
+                    )
+                    .attr('data-block', 'business-address')
+                );
+            }
+        })
 
+        .extend({
+            id: 'home-address',
+            index: 700,
+            draw: function (baton) {
+
+                var data = baton.data;
+
+                this.append(
                     block(gt('Home Address'),
                         address(data, 'home')
-                    ),
+                    )
+                    .attr('data-block', 'home-address')
+                );
+            }
+        })
 
+        .extend({
+            id: 'other-address',
+            index: 800,
+            draw: function (baton) {
+
+                var data = baton.data;
+
+                this.append(
                     block(gt('Other Address'),
                         address(data, 'other')
-                    ),
+                    )
+                    .attr('data-block', 'other-address')
+                );
+            }
+        })
 
+        .extend({
+            id: 'misc',
+            index: 900,
+            draw: function (baton) {
+
+                var data = baton.data;
+
+                this.append(
                     block(
                         //#. section name for contact fields in detail view
                         gt('Miscellaneous'),
                         // looks stupid but actually easier to read and not much shorter than any smart-ass solution
-                        simple(gt('Optional 01'), data.userfield01),
-                        simple(gt('Optional 02'), data.userfield02),
-                        simple(gt('Optional 03'), data.userfield03),
-                        simple(gt('Optional 04'), data.userfield04),
-                        simple(gt('Optional 05'), data.userfield05),
-                        simple(gt('Optional 06'), data.userfield06),
-                        simple(gt('Optional 07'), data.userfield07),
-                        simple(gt('Optional 08'), data.userfield08),
-                        simple(gt('Optional 09'), data.userfield09),
-                        simple(gt('Optional 10'), data.userfield10),
-                        simple(gt('Optional 11'), data.userfield11),
-                        simple(gt('Optional 12'), data.userfield12),
-                        simple(gt('Optional 13'), data.userfield13),
-                        simple(gt('Optional 14'), data.userfield14),
-                        simple(gt('Optional 15'), data.userfield15),
-                        simple(gt('Optional 16'), data.userfield16),
-                        simple(gt('Optional 17'), data.userfield17),
-                        simple(gt('Optional 18'), data.userfield18),
-                        simple(gt('Optional 19'), data.userfield19),
-                        simple(gt('Optional 20'), data.userfield20)
+                        simple(data, 'userfield01'),
+                        simple(data, 'userfield02'),
+                        simple(data, 'userfield03'),
+                        simple(data, 'userfield04'),
+                        simple(data, 'userfield05'),
+                        simple(data, 'userfield06'),
+                        simple(data, 'userfield07'),
+                        simple(data, 'userfield08'),
+                        simple(data, 'userfield09'),
+                        simple(data, 'userfield10'),
+                        simple(data, 'userfield11'),
+                        simple(data, 'userfield12'),
+                        simple(data, 'userfield13'),
+                        simple(data, 'userfield14'),
+                        simple(data, 'userfield15'),
+                        simple(data, 'userfield16'),
+                        simple(data, 'userfield17'),
+                        simple(data, 'userfield18'),
+                        simple(data, 'userfield19'),
+                        simple(data, 'userfield20')
                     )
+                    .attr('data-block', 'misc')
                 );
             }
         });
 
-
     // Resource description
     // only applies to resource because they have a "description" field.
     // contacts just have a "note"
@@ -519,9 +600,9 @@ define("io.ox/contacts/view-detail",
     var regPhone = /(\+?[\d\x20\/()]{4,})/g,
         regClean = /[^+0-9]/g;
 
-    ext.point("io.ox/contacts/detail/content").extend({
+    ext.point('io.ox/contacts/detail/content').extend({
         index: 'last',
-        id: "description", //
+        id: 'description', //
         draw: function (baton) {
 
             var str = $.trim(baton.data.description || ''), isHTML;
@@ -546,7 +627,7 @@ define("io.ox/contacts/view-detail",
                         // add callback?
                         baton.data.callbacks && 'extendDescription' in baton.data.callbacks ?
                             $('<a href="#">').text(gt('Copy to description'))
-                            .on('click', { description: str.replace(/[ \t]+/g, ' ') }, 'wurst' || baton.data.callbacks.extendDescription)
+                            .on('click', { description: $('<div>').html(str.replace(/[ \t]+/g, ' ').replace(/<br>/g, '\n')).text() }, baton.data.callbacks.extendDescription)
                             : []
                     )
                 );
@@ -554,7 +635,7 @@ define("io.ox/contacts/view-detail",
         }
     });
 
-    ext.point("io.ox/contacts/detail/content").extend({
+    ext.point('io.ox/contacts/detail/content').extend({
         index: 10000,
         id: 'qr',
         draw: function (baton) {
@@ -564,12 +645,12 @@ define("io.ox/contacts/view-detail",
                     show = function (e) {
                         e.preventDefault();
                         node.empty().busy();
-                        require(["io.ox/contacts/view-qrcode"], function (qr) {
+                        require(['io.ox/contacts/view-qrcode'], function (qr) {
                             var vc = qr.getVCard(data);
                             node.append(
                                 $('<span>').addClass('qrcode').append(
                                     $('<i class="icon-qrcode">'), $.txt(' '),
-                                    $("<a>", { href: '#' })
+                                    $('<a>', { href: '#' })
                                     .text(gt('Hide QR code'))
                                     .on('click', hide)
                                 )
@@ -586,7 +667,7 @@ define("io.ox/contacts/view-detail",
                             showLink
                         );
                     },
-                    showLink = $("<a>", { href: '#' }).text(gt('Show QR code')).on("click", show);
+                    showLink = $('<a>', { href: '#' }).text(gt('Show QR code')).on('click', show);
 
                 this.append(
                     node
@@ -600,7 +681,7 @@ define("io.ox/contacts/view-detail",
         }
     });
 
-    ext.point("io.ox/contacts/detail").extend({
+    ext.point('io.ox/contacts/detail').extend({
         index: 'last',
         id: 'breadcrumb',
         draw: function (baton) {
