@@ -1,16 +1,21 @@
 /**
- * All content on this website (including text, images, source code and any
- * other original works), unless otherwise noted, is licensed under a Creative
- * Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2012 Mail: info@open-xchange.com
+ * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
-define('io.ox/contacts/widgets/cityControlGroup', ['io.ox/backbone/forms', 'less!io.ox/contacts/widgets/widgets.less'], function (forms) {
-    "use strict";
+define('io.ox/contacts/widgets/cityControlGroup',
+    ['io.ox/backbone/forms',
+     'less!io.ox/contacts/widgets/widgets.less'
+    ], function (forms) {
+
+    'use strict';
 
     function CityControlGroup(options) {
         return new forms.ControlGroup(_.extend({}, {
@@ -42,14 +47,14 @@ define('io.ox/contacts/widgets/cityControlGroup', ['io.ox/backbone/forms', 'less
 
                 updateZip();
 
-                return this.nodes.bothElements = $("<span>").append(this.nodes.zipElement, $.txt(" "), this.nodes.element);
+                return this.nodes.bothElements = $('<span>').append(this.nodes.zipElement, $.txt(' '), this.nodes.element);
             },
 
             updateZipInModel: function () {
                 this.model.set(this.zipAttribute, this.nodes.zipElement.val(), {validate: true});
             },
 
-            updateZipInElement: function (valueFromModel) {
+            updateZipInElement: function () {
                 this.nodes.zipElement.val(this.model.get(this.zipAttribute));
             }
 
