@@ -1,12 +1,12 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
@@ -15,7 +15,8 @@ define('io.ox/core/api/apps',
     ['io.ox/core/event',
      'io.ox/core/extensions',
      'io.ox/core/manifests',
-     'io.ox/core/capabilities'], function (Events, ext, manifests, capabilities) {
+     'io.ox/core/capabilities'
+    ], function (Events, ext, manifests, capabilities) {
 
     'use strict';
 
@@ -49,7 +50,7 @@ define('io.ox/core/api/apps',
 
     // TODO: Make favorites dynamic
     var allFavorites = ['io.ox/portal', 'io.ox/mail', 'io.ox/contacts',
-                        'io.ox/calendar', 'io.ox/files', 'io.ox/tasks'];
+                        'io.ox/calendar', 'io.ox/tasks', 'io.ox/files'];
     _(allFavorites).each(function (id) {
         var app = appData.apps[id];
         if (app && capabilities.has(app.requires)) {
