@@ -1,19 +1,22 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Daniel Dickhaus <daniel.dickhaus@open-xchange.com>
  */
 
-define('io.ox/core/api/attachment', ['io.ox/core/http',
-                                     'io.ox/core/event',
-                                     'settings!io.ox/core'], function (http, Events, coreConfig) {
+define('io.ox/core/api/attachment',
+    ['io.ox/core/http',
+     'io.ox/core/event',
+     'settings!io.ox/core'
+    ], function (http, Events, coreConfig) {
+
     'use strict';
 
     var api = {
