@@ -1,24 +1,25 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Mario Scheliga <mario.scheliga@open-xchange.com>
  */
 
 define('io.ox/core/api/autocomplete',
-      ['io.ox/core/http',
-       'io.ox/core/capabilities',
-       'io.ox/mail/api',
-       'io.ox/contacts/api',
-       'io.ox/contacts/util',
-       'io.ox/core/api/resource',
-       'io.ox/core/api/group'], function (http, capabilities, mailAPI, contactsAPI, util, resourceAPI, groupAPI) {
+    ['io.ox/core/http',
+     'io.ox/core/capabilities',
+     'io.ox/mail/api',
+     'io.ox/contacts/api',
+     'io.ox/contacts/util',
+     'io.ox/core/api/resource',
+     'io.ox/core/api/group'
+    ], function (http, capabilities, mailAPI, contactsAPI, util, resourceAPI, groupAPI) {
 
     'use strict';
 
@@ -133,7 +134,7 @@ define('io.ox/core/api/autocomplete',
          */
         processContactResults: function (type, data, query, options) {
 
-            var tmp = [], hash = {}, self = this, list = [];
+            var tmp = [], hash = {}, self = this;
 
             //distinguish email and phone objects
             function getTarget(obj) {
