@@ -1,12 +1,13 @@
+// NOJSHINT
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Viktor Pracht <viktor.pracht@open-xchange.com>
  */
@@ -15,7 +16,8 @@ define.async('io.ox/core/date',
     ['io.ox/core/gettext',
      'settings!io.ox/core/settingOptions',
      'settings!io.ox/core',
-     'gettext!io.ox/core'], function (gettext, settingOptions, settings, gt) {
+     'gettext!io.ox/core'
+    ], function (gettext, settingOptions, settings, gt) {
 
     /*jshint white:false */
 
