@@ -1,12 +1,12 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
@@ -59,7 +59,7 @@ define('io.ox/core/event', function () {
             var myHub = hub; // Keep reference in case a handler cleans up the event dispatcher
             _(types.split(/\s+/)).each(function (type) {
                 myHub.triggerHandler.call(hub, type, args);
-                myHub.triggerHandler.call(hub, "triggered", _([type, args]).flatten()); // Allow stringing event hubs together
+                myHub.triggerHandler.call(hub, 'triggered', _([type, args]).flatten()); // Allow stringing event hubs together
             });
             return this;
         };
