@@ -1,7 +1,8 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
@@ -14,13 +15,14 @@
 
 define('io.ox/core/import/import',
     ['io.ox/core/extensions',
-    'io.ox/core/tk/dialogs',
-    'io.ox/core/tk/attachments',
-    'io.ox/core/api/folder',
-    'io.ox/core/api/import',
-    'io.ox/core/notifications',
-    'gettext!io.ox/core',
-    'less!io.ox/core/import/style.less'], function (ext, dialogs, attachments, folderAPI, api, notifications, gt) {
+     'io.ox/core/tk/dialogs',
+     'io.ox/core/tk/attachments',
+     'io.ox/core/api/folder',
+     'io.ox/core/api/import',
+     'io.ox/core/notifications',
+     'gettext!io.ox/core',
+     'less!io.ox/core/import/style.less'
+    ], function (ext, dialogs, attachments, folderAPI, api, notifications, gt) {
 
     'use strict';
 
@@ -43,7 +45,7 @@ define('io.ox/core/import/import',
 
             //lable and select
             nodes.label = $('<label>').text(gt('Format')).appendTo(nodes.row);
-            nodes.select = $('<select name="action">').appendTo(nodes.row);
+            nodes.select = $('<select name="action" tabindex="1" aria-label="' + gt('select format') + '">').appendTo(nodes.row);
 
             //add option
             formats = ext.point('io.ox/core/import/format').invoke('draw', null, baton)._wrapped;
@@ -108,10 +110,10 @@ define('io.ox/core/import/import',
 
     ext.point('io.ox/core/import/ignore_uuids').extend({
         id: 'default',
-        draw: function (baton) {
+        draw: function () {
             this.append(
                 $('<label class="checkbox">').append(
-                    $('<input type="checkbox" name="ignore_uuids">'),
+                    $('<input type="checkbox" tabindex="1" name="ignore_uuids">'),
                     gt('Ignore existing events. Helpful to import public holiday calendars, for example.')
                 )
             );
@@ -122,8 +124,8 @@ define('io.ox/core/import/import',
     ext.point('io.ox/core/import/buttons').extend({
         id: 'default',
         draw: function () {
-            this.addPrimaryButton('import', gt('Import'))
-                .addButton('cancel', gt('Cancel'));
+            this.addPrimaryButton('import', gt('Import'), 'import', {'tabIndex': '1'})
+                .addButton('cancel', gt('Cancel'), 'cancel', {'tabIndex': '1'});
         }
     });
 
@@ -136,7 +138,7 @@ define('io.ox/core/import/import',
                 form;
 
             //get folder and process
-            folderAPI.get({ folder: id }).done(function (folder) {
+            folderAPI.get({ folder: id }).done(function () {
                 dialog.build(function () {
                     form = $('<form>', { 'accept-charset': 'UTF-8', enctype: 'multipart/form-data', method: 'POST' });
                     this.getContentNode().append(form);
@@ -155,10 +157,6 @@ define('io.ox/core/import/import',
                     ext.point('io.ox/core/import/buttons')
                         .invoke('draw', this);
                     this.getPopup().addClass('import-dialog');
-                })
-                .show(function () {
-                    //focus
-                    this.find('select').focus();
                 });
                 dialog.on('import', function () {
                     var type = baton.nodes.select.val() || '',
@@ -220,7 +218,10 @@ define('io.ox/core/import/import',
                     })
                     .fail(failHandler);
                 })
-                .show();
+                .show(function () {
+                    //focus
+                    this.find('select').focus();
+                });
             });
         }
     };
