@@ -1,7 +1,8 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
@@ -12,9 +13,10 @@
  */
 
 define('io.ox/core/pubsub/settings/register',
-       ['io.ox/core/extensions',
-        'io.ox/core/capabilities',
-        'gettext!io.ox/core/pubsub'], function (ext, capabilities, gt) {
+    ['io.ox/core/extensions',
+     'io.ox/core/capabilities',
+     'gettext!io.ox/core/pubsub'
+    ], function (ext, capabilities, gt) {
 
     'use strict';
 
