@@ -1,12 +1,12 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2013
- * Mail: info@open-xchange.com
+ * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Frank Paczynski <frank.paczynski@open-xchange.com>
  */
@@ -16,7 +16,8 @@ define('io.ox/core/pubsub/util',
      'settings!io.ox/core',
      'io.ox/core/api/folder',
      'io.ox/core/pubsub/model',
-     'gettext!io.ox/mail'], function (api, coreConfig, folderAPI, model, gt) {
+     'gettext!io.ox/mail'
+    ], function (api, coreConfig, folderAPI, model, gt) {
 
     'use strict';
 
