@@ -1,18 +1,20 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/core/session', ['io.ox/core/http', 'io.ox/core/manifests'],
-function (http, manifests) {
+define('io.ox/core/session',
+    ['io.ox/core/http',
+     'io.ox/core/manifests'
+    ], function (http, manifests) {
 
     'use strict';
 
@@ -41,7 +43,7 @@ function (http, manifests) {
         manifests.reset();
         $('html').attr('lang', ox.language.split('_')[0]);
         // should not hide store() request here; made debugging hard
-        ox.trigger("change:session", ox.session);
+        ox.trigger('change:session', ox.session);
     };
 
     var that = {
