@@ -5,6 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
@@ -13,7 +14,8 @@
 define('io.ox/core/upsell',
     ['io.ox/core/capabilities',
      'settings!io.ox/core',
-     'gettext!io.ox/core'], function (capabilities, settings, gt) {
+     'gettext!io.ox/core'
+    ], function (capabilities, settings, gt) {
 
     'use strict';
 
