@@ -1,22 +1,26 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
 
-define('io.ox/dev/chineseRoom/room', ['io.ox/realtime/groups', 'io.ox/core/event'], function (groups, Events) {
+define('io.ox/dev/chineseRoom/room',
+    ['io.ox/realtime/groups',
+     'io.ox/core/event'
+    ], function (groups, Events) {
+
     'use strict';
 
     function ChineseRoom(roomName) {
         var self = this;
-        this.group = groups.getGroup("synthetic.china://" + roomName);
+        this.group = groups.getGroup('synthetic.china://' + roomName);
         this.collection = new Backbone.Collection();
         Events.extend(this);
 
@@ -24,7 +28,6 @@ define('io.ox/dev/chineseRoom/room', ['io.ox/realtime/groups', 'io.ox/core/event
             return this.group.join(options);
         };
 
-
         this.leave = function (options) {
             return this.group.leave(options);
         };
@@ -36,15 +39,15 @@ define('io.ox/dev/chineseRoom/room', ['io.ox/realtime/groups', 'io.ox/core/event
 
         this.say = function (text) {
             return this.group.send({
-                element: "message",
+                element: 'message',
                 payloads: [
                     {
-                        element: "action",
-                        data: "say"
+                        element: 'action',
+                        data: 'say'
                     },
                     {
-                        element: "message",
-                        namespace: "china",
+                        element: 'message',
+                        namespace: 'china',
                         data: text
                     }
                 ]
@@ -54,15 +57,15 @@ define('io.ox/dev/chineseRoom/room', ['io.ox/realtime/groups', 'io.ox/core/event
         this.sayAndTrace = function (text, tracer) {
             return this.group.send({
                 tracer: tracer,
-                element: "message",
+                element: 'message',
                 payloads: [
                     {
-                        element: "action",
-                        data: "say"
+                        element: 'action',
+                        data: 'say'
                     },
                     {
-                        element: "message",
-                        namespace: "china",
+                        element: 'message',
+                        namespace: 'china',
                         data: text
                     }
                 ]
@@ -71,11 +74,11 @@ define('io.ox/dev/chineseRoom/room', ['io.ox/realtime/groups', 'io.ox/core/event
 
         this.requestLog = function () {
             return this.group.send({
-                element: "message",
+                element: 'message',
                 payloads: [
                     {
-                        element: "action",
-                        data: "getLog"
+                        element: 'action',
+                        data: 'getLog'
                     }
                 ]
             });
@@ -83,49 +86,49 @@ define('io.ox/dev/chineseRoom/room', ['io.ox/realtime/groups', 'io.ox/core/event
 
         this.requestLogByQuery = function () {
             return this.group.query({
-                element: "message",
+                element: 'message',
                 payloads: [
                     {
-                        element: "action",
-                        data: "getLog"
+                        element: 'action',
+                        data: 'getLog'
                     }
                 ]
             });
         };
 
-        this.group.on("receive", function (e, m) {
+        this.group.on('receive', function (e, m) {
             if (false && m.log) {
-                console.log("-------------------------");
+                console.log('-------------------------');
                 _(m.log).each(function (entry) {
                     console.log(entry);
                 });
-                console.log("-------------------------");
+                console.log('-------------------------');
             }
-            var message = m.get("china", "message");
+            var message = m.get('china', 'message');
 
             if (message) {
                 console.log(m.from, message.data);
-                self.trigger("received", {from: m.from, message: message.data});
+                self.trigger('received', {from: m.from, message: message.data});
 
             }
 
-            if (m.get("china", "replay")) {
-                _(m.getAll("china", "replay")).each(function (m) {
+            if (m.get('china', 'replay')) {
+                _(m.getAll('china', 'replay')).each(function (m) {
                     console.log(m.data.sender, m.data.message);
                 });
             }
         });
 
-        this.group.on("offline", function () {
-            console.log("Offline!");
+        this.group.on('offline', function () {
+            console.log('Offline!');
         });
 
-        this.group.on("online", function () {
-            console.log("Online!");
+        this.group.on('online', function () {
+            console.log('Online!');
         });
 
-        this.group.on("reset", function () {
-            console.log("Reset!");
+        this.group.on('reset', function () {
+            console.log('Reset!');
         });
 
     }
