@@ -1,12 +1,12 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
@@ -16,10 +16,11 @@ define('io.ox/files/main',
     ['io.ox/core/commons',
      'gettext!io.ox/files',
      'settings!io.ox/files',
+     'io.ox/core/api/folder',
      'io.ox/core/extPatterns/actions',
      'io.ox/files/actions',
      'less!io.ox/files/style.less'
-    ], function (commons, gt, settings, actions) {
+    ], function (commons, gt, settings, folderAPI, actions) {
 
     'use strict';
 
@@ -28,6 +29,18 @@ define('io.ox/files/main',
         // app window
         win;
 
+    //map old settings/links
+    function map(pers) {
+        var mapping;
+        if (/^(icons)$/.test(pers)) {
+            //support old setting value
+            mapping = 'fluid:icon';
+        } else if (!/^(fluid:list|fluid:icon|fluid:tile)$/.test(pers)) {
+            mapping = 'fluid:list';
+        }
+        return mapping || pers;
+    }
+
     // launcher
     app.setLauncher(function (options) {
         // get window
@@ -50,16 +63,15 @@ define('io.ox/files/main',
             actions.invoke('io.ox/files/actions/move', null, baton);
         });
 
+        // fix missing default folder
+        options.folder = options.folder || folderAPI.getDefaultFolder('infostore') || 9;
+
         // go!
         return commons.addFolderSupport(app, null, 'infostore', options.folder)
             .pipe(commons.showWindow(win))
             .done(function () {
-                // switch to view in url hash or default
-                var p = settings.get('view', 'icons');
-                if (!/^(icons|list)$/.test(p)) {
-                    p = 'icons';
-                }
-                ox.ui.Perspective.show(app, options.perspective || _.url.hash('perspective') || p);
+                var pers = map(options.perspective || _.url.hash('perspective') || settings.get('view', 'fluid:list'));
+                ox.ui.Perspective.show(app, pers);
             });
     });
 
