@@ -1,34 +1,37 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
  */
 
 define('io.ox/mail/autoforward/settings/register',
-        ['io.ox/core/extensions', 'io.ox/core/notifications',
-         'io.ox/core/api/user', 'gettext!io.ox/mail'], function (ext, notifications, userAPI, gt) {
+    ['io.ox/core/extensions',
+     'io.ox/core/notifications',
+     'io.ox/core/api/user',
+     'gettext!io.ox/mail'
+    ], function (ext, notifications, userAPI, gt) {
 
     'use strict';
 
     var filterModel;
 
-    ext.point("io.ox/settings/pane").extend({
+    ext.point('io.ox/settings/pane').extend({
         id: 'io.ox/autoforward',
-        title: gt("Auto Forward"),
+        title: gt('Auto Forward'),
         ref: 'io.ox/autoforward',
         loadSettingPane: false,
         index: 425,
         lazySaveSettings: true
     });
 
-    ext.point("io.ox/autoforward/settings/detail").extend({
+    ext.point('io.ox/autoforward/settings/detail').extend({
         index: 100,
         draw: function () {
             var $node = this,
@@ -36,7 +39,7 @@ define('io.ox/mail/autoforward/settings/register',
 
             $node.append($container);
 
-            require(["io.ox/mail/autoforward/settings/filter"], function (filters) {
+            require(['io.ox/mail/autoforward/settings/filter'], function (filters) {
 
                 userAPI.get().done(function (user) {
                     var multiValues = {};
@@ -48,7 +51,7 @@ define('io.ox/mail/autoforward/settings/register',
                             msg = gt('Unable to load mail filter settings.');
                         }
                         $container.append(
-                            $.fail(msg || gt("Couldn't load your auto forward."), function () {
+                            $.fail(msg || gt('Couldn\'t load your auto forward.'), function () {
                                 filters.editAutoForward($node).done(function () {
                                     $container.find('[data-action="discard"]').hide();
                                 });
