@@ -1,12 +1,12 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
@@ -18,7 +18,8 @@ define('io.ox/mail/view-grid-template',
      'io.ox/core/api/account',
      'io.ox/core/emoji/util',
      'gettext!io.ox/core/mail',
-     'less!io.ox/mail/style.less'], function (util, api, VGrid, account, emoji, gt) {
+     'less!io.ox/mail/style.less'
+    ], function (util, api, VGrid, account, emoji, gt) {
 
     'use strict';
 
@@ -39,7 +40,7 @@ define('io.ox/mail/view-grid-template',
                 var from, date, priority, subject, attachment, threadSize, threadSizeCount, threadSizeIcon,
                     flag, answered, forwarded, unread, account = null, touchHelper = $();
                 if (_.device('smartphone')) {
-                    touchHelper = $('<div class="touch-helper">');
+                    touchHelper = $('<div class="touch-helper ignoreheight">');
                 }
                 this.addClass('mail').append(
                     $('<div>').append(
@@ -86,8 +87,12 @@ define('io.ox/mail/view-grid-template',
             },
             set: function (data, fields, index) {
                 fields.priority.empty().append(util.getPriority(data));
-                var subject = _.escape($.trim(data.subject));
+                var subject = _.escape($.trim(data.subject)),
+                    fromlist = data.from || [['', '']],
+                    a11yLabel = util.getDisplayName(fromlist[0]);
+                a11yLabel += ', ' + util.getTime(data.received_date);
                 if (subject !== '') {
+                    a11yLabel += ', ' + subject;
                     fields.subject.removeClass('empty').empty().html(
                         emoji.processEmoji(subject)
                     );
@@ -130,7 +135,10 @@ define('io.ox/mail/view-grid-template',
                 if (util.isForwarded(thread, data)) {
                     this.addClass('forwarded');
                 }
-                this.attr('data-index', index);
+                this.attr({
+                    'data-index': index,
+                    'aria-label': a11yLabel
+                });
             }
         },
 
@@ -151,7 +159,6 @@ define('io.ox/mail/view-grid-template',
                     }
                     // draw labels
                     _(subset).each(function (data, index) {
-                        var color = api.tracker.getColorLabel(data);
                         self.append(
                             $('<div class="thread-summary-item selectable">')
                             .addClass(util.isUnseen(data) ? 'unread' : undefined)
