@@ -1,18 +1,19 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2012
- * Mail: info@open-xchange.com
+ * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Tobias Prinz <tobias.prinz@open-xchange.com>
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
-define('io.ox/oauth/proxy', ["io.ox/core/http"], function (http) {
-    "use strict";
+define('io.ox/oauth/proxy', ['io.ox/core/http'], function (http) {
+
+    'use strict';
 
     var that = {
         request: function (options) {
@@ -27,7 +28,7 @@ define('io.ox/oauth/proxy', ["io.ox/core/http"], function (http) {
                 delete options.account;
             }
             return http.PUT({
-                module: "oauth/proxy",
+                module: 'oauth/proxy',
                 params: params,
                 data: options
             });
