@@ -1,24 +1,24 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Alexander Quast <alexander.quast@open-xchange.com>
  */
 
 define('io.ox/participants/model',
-        ['io.ox/core/api/user',
-         'io.ox/core/api/group',
-         'io.ox/core/api/resource',
-         'io.ox/contacts/api',
-         'io.ox/contacts/util',
-         'io.ox/core/util'
-         ], function (userAPI, groupAPI, resourceAPI, contactAPI, util, coreUtil) {
+    ['io.ox/core/api/user',
+     'io.ox/core/api/group',
+     'io.ox/core/api/resource',
+     'io.ox/contacts/api',
+     'io.ox/contacts/util',
+     'io.ox/core/util'
+    ], function (userAPI, groupAPI, resourceAPI, contactAPI, util, coreUtil) {
 
     'use strict';
     // TODO: Bulk Loading
@@ -83,7 +83,7 @@ define('io.ox/participants/model',
             });
         },
 
-        fetch: function (options) {
+        fetch: function () {
 
             var self = this, df = new $.Deferred();
 
@@ -204,7 +204,7 @@ define('io.ox/participants/model',
                 // Deduplication
                 var idMap = {};
                 var duplicates = [];
-                self.each(function (p, index) {
+                self.each(function (p) {
                     if (idMap[p.id]) {
                         duplicates.push(p);
                     } else {
@@ -217,7 +217,7 @@ define('io.ox/participants/model',
 
         model: ParticipantModel,
 
-        addUniquely: function (models, options) {
+        addUniquely: function (models) {
             var self = this;
             if (!_.isArray(models)) {
                 models = [models];
