@@ -5,12 +5,13 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/portal/feed', ['io.ox/core/extensions'], function (ext) {
+define('io.ox/portal/feed', function () {
 
     'use strict';
 
@@ -47,7 +48,7 @@ define('io.ox/portal/feed', ['io.ox/core/extensions'], function (ext) {
         return response;
     };
 
-    Feed.prototype.appendLimitOffset = function (url, count, offset) {
+    Feed.prototype.appendLimitOffset = function (url) {
         return url;
     };
 
