@@ -1,23 +1,25 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2012
- * Mail: info@open-xchange.com
+ * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Daniel Dickhaus <daniel.dickhaus@open-xchange.com>
  */
 
-define('io.ox/tasks/model', ['io.ox/tasks/api',
-                             'io.ox/backbone/modelFactory',
-                             'io.ox/backbone/validation',
-                             'io.ox/core/extensions',
-                             'io.ox/participants/model',
-                             'io.ox/core/date',
-                             'gettext!io.ox/tasks'], function (api, ModelFactory, Validations, ext, pModel, date, gt) {
+define('io.ox/tasks/model',
+    ['io.ox/tasks/api',
+     'io.ox/backbone/modelFactory',
+     'io.ox/backbone/validation',
+     'io.ox/core/extensions',
+     'io.ox/participants/model',
+     'io.ox/core/date',
+     'gettext!io.ox/tasks'
+    ], function (api, ModelFactory, Validations, ext, pModel, date, gt) {
 
     'use strict';
 
@@ -45,7 +47,7 @@ define('io.ox/tasks/model', ['io.ox/tasks/api',
                     var participants = this._participants = new pModel.Participants(this.get('participants'));
                     participants.invoke('fetch');
 
-                    function resetList(participant) {
+                    function resetList() {
                         if (changeParticipantsUpdate) {
                             return;
                         }
