@@ -1,20 +1,23 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2012
- * Mail: info@open-xchange.com
+ * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
  */
 
 define('io.ox/tasks/settings/pane',
-       ['settings!io.ox/tasks', 'io.ox/tasks/settings/model',
-        'dot!io.ox/tasks/settings/form.html', 'io.ox/core/extensions',
-        'gettext!io.ox/tasks'], function (settings, tasksSettingsModel, tmpl, ext, gt) {
+    ['settings!io.ox/tasks',
+     'io.ox/tasks/settings/model',
+     'dot!io.ox/tasks/settings/form.html',
+     'io.ox/core/extensions',
+     'gettext!io.ox/tasks'
+    ], function (settings, tasksSettingsModel, tmpl, ext, gt) {
 
     'use strict';
 
@@ -33,9 +36,9 @@ define('io.ox/tasks/settings/pane',
         tasksViewSettings;
 
     var TasksSettingsView = Backbone.View.extend({
-        tagName: "div",
+        tagName: 'div',
         _modelBinder: undefined,
-        initialize: function (options) {
+        initialize: function () {
             // create template
             this._modelBinder = new Backbone.ModelBinder();
 
@@ -69,7 +72,7 @@ define('io.ox/tasks/settings/pane',
     ext.point('io.ox/tasks/settings/detail').extend({
         index: 200,
         id: 'taskssettings',
-        draw: function (data) {
+        draw: function () {
 
             tasksViewSettings = new TasksSettingsView({model: tasksSettings});
             var holder = $('<div>').css('max-width', '800px');
