@@ -1,26 +1,28 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Tobias Prinz <tobias.prinz@open-xchange.com>
  */
 
-define("plugins/portal/dummy/register", ["io.ox/core/extensions"], function (ext) {
+define('plugins/portal/dummy/register', $.noop);
 
-    "use strict";
+/*define('plugins/portal/dummy/register', ['io.ox/core/extensions'], function (ext) {
+
+    'use strict';
 
     var load = function () {
-        return $.Deferred().resolve($('<div>').text("Blablabla"));
+        return $.Deferred().resolve($('<div>').text('Blablabla'));
     };
     var drawTypeA = function () {
         var $node = $('<div class="io-ox-tile-container io-ox-portal-typeA">').append(
-            $('<div class="io-ox-portal-title">').text("Dummy Type A"),
+            $('<div class="io-ox-portal-title">').text('Dummy Type A'),
             $('<div class="io-ox-portal-content">').append(
                 $('<div class="io-ox-portal-item">').text('item #1'),
                 $('<div class="io-ox-portal-item">').text('item #2'),
@@ -33,8 +35,8 @@ define("plugins/portal/dummy/register", ["io.ox/core/extensions"], function (ext
                 $('<div class="io-ox-portal-item">').text('item #9')
             ),
             $('<div class="io-ox-portal-actions">').append(
-                $('<i class="icon-edit io-ox-portal-tile-action">').text(" "),
-                $('<i class="icon-remove io-ox-portal-tile-action">').text(" ")
+                $('<i class="icon-edit io-ox-portal-tile-action">').text(' '),
+                $('<i class="icon-remove io-ox-portal-tile-action">').text(' ')
             )
         );
         return $node;
@@ -46,9 +48,9 @@ define("plugins/portal/dummy/register", ["io.ox/core/extensions"], function (ext
             'http://www.open-xchange.com/typo3conf/ext/opx/Resources/Public/Image/portal/icon/carousel/ignite.png'][pos];
         var $node = $('<div class="io-ox-tile-container io-ox-portal-typeB">').append(
             $('<div class="io-ox-portal-image">').attr({'style': 'background-image: url(' + img + ')'}),
-            $('<div class="io-ox-portal-title">').text("Dummy Type B" + pos).append(
-                $('<i class="icon-edit io-ox-portal-action">').text(" "),
-                $('<i class="icon-remove io-ox-portal-action">').text(" ")
+            $('<div class="io-ox-portal-title">').text('Dummy Type B' + pos).append(
+                $('<i class="icon-edit io-ox-portal-action">').text(' '),
+                $('<i class="icon-remove io-ox-portal-action">').text(' ')
             )
         );
         return $node;
@@ -62,17 +64,17 @@ define("plugins/portal/dummy/register", ["io.ox/core/extensions"], function (ext
     };
     var draw = function () {
         var $node = $('<div class="io-ox-portal-dummy">').appendTo(this).append(
-            $('<h1 class="clear-title">').text("Dummy"),
-            $('<p>').text("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt " +
-            "ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi" +
-            " ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum" +
-            " dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia" +
-            " deserunt mollit anim id est laborum.")
+            $('<h1 class="clear-title">').text('Dummy'),
+            $('<p>').text('Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ' +
+            'ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi' +
+            ' ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum' +
+            ' dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia' +
+            ' deserunt mollit anim id est laborum.')
         );
         return $.Deferred().resolve($node);
     };
     // for (var i = 0; i < 25; i++) {
-    //     ext.point("io.ox/portal/widget").extend({
+    //     ext.point('io.ox/portal/widget').extend({
     //         id: 'dummy' + i,
     //         index: 500 + i,
     //         title: 'Dummy #' + i,
@@ -82,3 +84,4 @@ define("plugins/portal/dummy/register", ["io.ox/core/extensions"], function (ext
     //     });
     // }
 });
+*/
\ No newline at end of file
