@@ -5,6 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
@@ -13,7 +14,8 @@
 define('plugins/portal/upsell/register',
     ['io.ox/core/extensions',
      'io.ox/files/api',
-     'gettext!plugins/portal'], function (ext, api, gt) {
+     'gettext!plugins/portal'
+    ], function (ext, api, gt) {
 
     'use strict';
 
@@ -23,7 +25,7 @@ define('plugins/portal/upsell/register',
 
         title: title,
 
-        preview: function (baton) {
+        preview: function () {
 
             this.addClass('hide-title').append(
                 $('<div class="content centered" style="cursor: pointer; padding-top: 3em;">').append(
