@@ -685,6 +685,7 @@
         $parent.toggleClass('open');
         if (phone) {
           ox.disable(true);
+          $('#io-ox-core').addClass('menu-blur');
           $parent.data('menu').show();
         }
       }
@@ -740,10 +741,11 @@
     // Ignore ctrl click to make firefox mac users happy
     if (e && e.ctrlKey) { return; }
     // on phone close only on item select or close item in the list
-    if (phone && e && $(e.target).attr('id') === "background_loader") {
+    if (phone && e && $(e.target).attr('id') === "background-loader") {
       return;
     }
     if (phone) {
+      $('#io-ox-core').removeClass('menu-blur');
       $('.dropdown-menu').hide();
       ox.idle();
     }
