@@ -5,16 +5,13 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Julian Bäume <julian.baeume@open-xchange.com>
  */
 define(function () {
     describe('require static files', function () {
-        afterEach(function () {
-            this.handleExpectedFail({'require static files should fetch static files via backend.': true});
-        });
-
         it('should fetch static files via backend', function () {
             var def = require(['apps/file/doesnt/exist.js']);
 
